package com.yanzhu.manage.service;

import java.util.List;
import com.yanzhu.manage.domain.BusExamQuestion;

/**
 * 基础题库Service接口
 * 
 * @author JiangYuQi
 * @date 2024-08-25
 */
public interface IBusExamQuestionService 
{
    /**
     * 查询基础题库
     * 
     * @param id 基础题库主键
     * @return 基础题库
     */
    public BusExamQuestion selectBusExamQuestionById(Long id);

    /**
     * 查询基础题库列表
     * 
     * @param busExamQuestion 基础题库
     * @return 基础题库集合
     */
    public List<BusExamQuestion> selectBusExamQuestionList(BusExamQuestion busExamQuestion);

    /**
     * 新增基础题库
     * 
     * @param busExamQuestion 基础题库
     * @return 结果
     */
    public int insertBusExamQuestion(BusExamQuestion busExamQuestion);

    /**
     * 修改基础题库
     * 
     * @param busExamQuestion 基础题库
     * @return 结果
     */
    public int updateBusExamQuestion(BusExamQuestion busExamQuestion);

    /**
     * 批量删除基础题库
     * 
     * @param ids 需要删除的基础题库主键集合
     * @return 结果
     */
    public int deleteBusExamQuestionByIds(Long[] ids);

    /**
     * 删除基础题库信息
     * 
     * @param id 基础题库主键
     * @return 结果
     */
    public int deleteBusExamQuestionById(Long id);
}
